timestep = 0.1; % in days
times = (0:timestep:(60*24))'/24; % run for 60 days worth of tides

t_start = 631967; % start time
Model='O:/Documents/TMD/Model_CATS2008'; % using CATS2008
tidal_thwaites = tmd_tide_pred(Model,t_start + times,-75.083,-107.083,'z'); % location representative of Thwaites

bed = 0:0.1:1000; 
av_spacing = 6; % distance between ribs, in metres
eff_theta = 0.02:0.01:0.04; % effective bedslope (as a gradient)
mean_flux = 0.5*timestep; % average background till flux to the grounding line, in m^2/timestep
erosion_rate = 0.0005; % average erosion rate due to water drainage, in m^2/timestep/m exposed
d_comp = 0.15; % maximum compaction depth, in m

% select the model, calculate and plot the bed geometry

for i = 1:length(eff_theta)

angle = eff_theta(i);    
%[depths(i,:), xs(i,:), gl_loc(i,:)] = flux_only_model_s1(av_spacing,tidal_thwaites,times,angle,mean_flux,bed);
%[depths(i,:), xs(i,:), gl_loc(i,:)] = extrusion_model_s1(av_spacing,tidal_thwaites,times,angle,mean_flux,0,bed);
[depths(i,:), xs(i,:), gl_loc(i,:)] = extrusion_model_s1(av_spacing,tidal_thwaites,times,angle,0,d_comp,bed);
%[depths(i,:), xs(i,:), gl_loc(i,:)] = resuspension_model_s1(av_spacing,tidal_thwaites,times,angle,erosion_rate,bed);

end

% plot the corresponding position in the tidal cycle
t_end = find(gl_loc(3,:) < xs(3,end),1,'last'); % find when the grounding line migrates out of the modelled area


subplot(3,2,1:2:3)
hold on

for i = 1:length(eff_theta)
    
plot(xs(i,:)-xs(i,1)+gl_loc(1,t_end)-gl_loc(i,t_end),depths(i,:) + i) % plot final bed geometry, offset to show multiple angles on same plot

end
xlabel('Position (m)')
ylabel('Rib height (offset)')
legend_text = {'\theta =0.02','\theta =0.03','\theta =0.04'};
%legend_text = {'\theta =0.01','\theta =0.02','\theta =0.03'};
legend(legend_text,'location','southeast')
axis([0 (xs(3,end)-xs(3,1)+gl_loc(1,t_end)-gl_loc(3,t_end)) -inf inf])

t_start = find(gl_loc(3,:)< (xs(3,1)-gl_loc(1,t_end)+gl_loc(3,t_end)),1,'last'); % since spin-up is cropped, find the time corresponding to the start

subplot(3,2,5)
plot(times(t_start:t_end)-times(t_start),tidal_thwaites(t_start:t_end))
axis([-inf inf -2 2])
xlabel('Time (days)')
ylabel('Tidal height (m)')

% select a section from the middle of the run to analyse the periodicity of
% the ribs
x = xs(3,500:2500);
depth = depths(3,500:2500);
subplot(1,2,2)

[dips,locs] = findpeaks(-depth,'MinPeakProminence',0.02,'MinPeakDistance',11);
bed = interp1(x(locs),-dips,x);
[pks,locs] = findpeaks(depth-bed,'MinPeakProminence',0.02,'MinPeakDistance',11);

spacing = x(locs(2:end))-x(locs(1:end-1));
heights = pks;

bar(heights)
hold on
ylabel('Rib height')
yyaxis right
scatter(1:length(spacing),spacing,'filled')
ylabel('Rib spacing (m)')
xlabel('Rib number')
axis([-inf inf 0 inf])